@@ -1,9 +1,6 @@
-from pprint import pprint, pformat
-import warnings
-
 try:
     import ujson as json
-except:
+except:  # noqa: E722
     import json
 import logging
 import asyncio
@@ -27,7 +24,7 @@ from .wrappers import (
     _default_to_locale,
     _inject_user_id,
 )
-from .base_client import _BaseClient, TOKEN_EXPIRED_MSG, BASE_URI
+from .base_client import _BaseClient, TOKEN_EXPIRED_MSG
 
 
 logger = logging.getLogger(__name__)
@@ -420,9 +417,7 @@ class AsyncSpotify(_BaseClient):
         self._update_user_creds_with(new_creds_obj)
 
     @_set_empty_user_creds_if_none
-    async def build_user_creds(
-        self, grant, set_user_creds=True
-    ):
+    async def build_user_creds(self, grant, set_user_creds=True):
         """
         Second part of OAuth2 authorization code flow, Raises an AuthError if unauthorized
 
@@ -1325,6 +1320,41 @@ class AsyncSpotify(_BaseClient):
         """
         return args, kwargs
 
+    @_dispatch_request
+    async def replace_playlist_tracks(self, *args, **kwargs):
+        """
+        Replace all tracks of a playlist with tracks of your choice
+
+        Arguments:
+
+            playlist_id:
+
+                * Required
+
+            track_ids:
+
+                * track_ids not full URIs
+
+                * Optional
+
+            to_gather (bool):
+
+                * Whether or not this resource/method will be gathered with ``AsyncSpotify.gather`` or ``AsyncSpotify.gather_now``
+
+                * Optional
+
+                * Default: ``False``
+
+        Returns:
+
+            dict:
+
+        Raises:
+
+            pyfy.excs.ApiError:
+        """
+        return args, kwargs
+
     @_dispatch_request
     async def delete_playlist_tracks(self, *args, **kwargs):
         """
