@@ -1,23 +1,17 @@
 try:
     import ujson as json
-except:
+except:  # noqa: E722
     import json
 import base64
 import warnings
 import datetime
 from urllib.parse import urlencode
 
-from requests import Request, Response
+from requests import Request
 
-from .creds import (
-    ClientCreds,
-    UserCreds,
-    _set_empty_client_creds_if_none,
-    _set_empty_user_creds_if_none,
-)
+from .creds import ClientCreds, UserCreds, _set_empty_client_creds_if_none
 from .excs import ApiError, AuthError
 from .utils import (
-    _safe_getitem,
     _get_key_recursively,
     _build_full_url,
     _safe_comma_join_list,
@@ -515,11 +509,11 @@ class _BaseClient:
         data = dict(name=name)
 
         if description is not None:
-            data['description'] = description
+            data["description"] = description
         if public is not None:
-            data['public'] = public
+            data["public"] = public
         if collaborative is not None:
-            data['collaborative']
+            data["collaborative"] = collaborative
 
         return self._create_request(
             method="POST", url=_build_full_url(url, params), json=data
@@ -616,6 +610,24 @@ class _BaseClient:
             method="PUT", url=_build_full_url(url, params), json=data
         )
 
+    def _prep_replace_playlist_tracks(self, playlist_id, track_ids=None, **kwargs):
+        url = BASE_URI + "/playlists/" + playlist_id + "/tracks"
+        params = {}
+        data = {}
+
+        if track_ids is not None:
+            if isinstance(track_ids, str):
+                uris = [f"spotify:track:{track_ids}"]
+            elif isinstance(track_ids, (list, tuple, set)):
+                uris = [f"spotify:track:{track_id}" for track_id in track_ids]
+            else:
+                raise TypeError("Invalid track_ids type")
+            data["uris"] = uris
+
+        return self._create_request(
+            method="PUT", url=_build_full_url(url, params), json=data
+        )
+
     def _prep_delete_playlist_tracks(self, playlist_id, track_ids, **kwargs):
         """ 
         track_ids types supported:
